import javax.swing.table.*;

/**
 * The Level class is a tool used by the user to create custom levels
 * for use in the game.
 *
 * @author 	Kevin Blomseth
 * @date		11/22/01
 * @version 1.3
 *
 */
//Version History
//  11/22/01 Kevin Blomseth added algorithm pseudocode
//	11/28/01 Kevin Blomseth modified javadoc headers and added variable
//			 descriptions
//  01/16/02 Joshua Thompson added pseudocode for the AbstractTableModel

public class Level extends AbstractTableModel
{
    /**
     * The name of the level.
     */
    private String levelName;
    /** The board will be a 25 by 25 two dimensional array used to represent
     *  each square on the playing field.
     */
    private Square[][] board;

    /**
     * Constructor - initializes the Square[][] board.
     */
    public Level()
    {
        // INIT the board = new Square[Constants.maxRow][Constants.maxCol]
        board = new Square[Constants.maxRow][Constants.maxCol];
    }
    /**
     * Returns the level name.
     */
    public String getLevelName()
    {
        // RETURN levelName
        return levelName;
    }

    /**
     * Sets the level name to the parameter passed.
     *
     * @param name the new name of the level
     */
    public void setLevelName(String name)
    {
        // SET levelName = name
        levelName = name;
    }

    /**
     * Changes the properties of the input square to whatever object is being
     * assigned to it.
     *
     * @param obj       The object being assigned to the square
     * @param row		The row position of the object
     * @param col		The col position of the object
     */
    public void setValueAt(Square obj, int row, int col)
    {
        // SET the location corresponding to row and col in board equal to obj.
        board[row][col] = obj;
    }

    /**
     * Returns the number of rows in the map.
     *
     * @return Returns the number of rows in the map.
     */
    public int getRowCount()
    {
        // RETURN Constants.maxRow
        return Constants.maxRow;
    }

    /**
     * Used by the JTable display to determine the number of columns.  Returns
     * zero because the columns are added manually.
     *
     * @return Returns zero.
     */
    public int getColumnCount()
    {
        // RETURN 0
        return 0;
    }

    /**
     * Returns the Square located at the row and column passed.
     *
     * @param row the row location of the requested square.
     * @param column the column location of the requested square.
     *
     * @return the Square located at row and column in board[][]
     */
    public Object getValueAt(int row, int column)
    {
        // RETURN board[row][column]
        return (Object)board[row][column];
    }
}
