/**
 * The Move class represents a move made by the robot on a map. It contains
 * the direction that was moved and whether or not a crate was moved or
 * incinerated during that move.
 *
 * @author    Kevin Blomseth
 * @date      11/28/01
 * @version   1.3
 *
 */
//Version History
//  11/22/01 Kevin Blomseth added algorithm pseudocode
//  11/28/01 Kevin Blomseth added object comments and changed header
//  12/01/01 Kevin Blomseth added java code

public class Move
{
    /**
     * Says whether or not a crate was moved during the move.
     */
    private boolean crateMoved;

    /**
     * Says whether or not a crate was incinerated during the move.
     */
    private boolean crateIncinerated;

    /**
     * Says the direction that the robot moved.
     */
    private boolean robotMoved;

    /**
     * Says the direction that the robot moved.
     */
    private Direction direction;

    /**
        * Constructor for the Move Class
        *
        * @param dir   The direction of the move
        * @param crate Whether or not a crate was moved
        * @param incinerated Whether or not a crate was moved
        */
    public Move(Direction dir, boolean crate, boolean incinerated, boolean moved)
    {
        // SET direction to dir
        // SET crateMoved to crate
        // SET crateIncinerated to incinerated
        this.direction = dir;
        this.crateMoved = crate;
        this.crateIncinerated = incinerated;
        this.robotMoved = moved;
    }

    /**
     * Returns the direction of the move that just occured.
     *
     * @return The direction of the move
     */
    public Direction getDirection()
    {
        //RETURN direction
        return direction;
    }

    /**
     * Sets the direction that the robot moved.
     *
     * @param dir The direction of the move
     */
    public void setDirection(Direction dir)
    {
        //SET direction to dir
        direction = dir;
    }

    /**
     * Returns whether or not the crate was moved in the move.
     *
     * @return true if a crate was moved, otherwise false
     */
    public boolean hasCrateMoved()
    {
        //RETURN crateMoved
        return crateMoved;
    }

    /**
     * Sets whether or not a crate was moved in the move.
     *
     * @param moved	True if crate was moved
     *                   False otherwise
     */
    public void setCrateMoved(boolean moved)
    {
        //SET crateMoved to moved
        crateMoved = moved;
    }

    /**
        * Returns whether or not the crate was incinerated.
        *
        * @return true if a crate was incinerated, otherwise false
        */
    public boolean wasIncinerated()
    {
        //RETURN crateIncinerated
        return crateIncinerated;
    }

    /**
     * Sets whether or not a crate was incinerated on a move.
     *
     * @param incinerated	True if crate was incinerated
     *						False otherwise
     */
    public void setIncinerated(boolean incinerated)
    {
        //SET crateIncinerated to incinerated
        crateIncinerated = incinerated;
    }

    /**
        * Returns whether or not the robot was moved in the move.
        *
        * @return true if a robot was moved, otherwise false
        */
    public boolean hasRobotMoved()
    {
        //RETURN robotMoved
        return robotMoved;
    }

    /**
     * Sets whether or not a robot was moved in the move.
     *
     * @param moved	True if robot was moved
     *                   False otherwise
     */
    public void setRobotMoved(boolean moved)
    {
        //SET robotMoved to moved
        robotMoved = moved;
    }
}
